@@ -363,12 +363,18 @@ providers_list = {
     # 'mangaonlinehere_com': [
     #     r'mangaonlinehere\.com/(manga-info|read-online)/.',
     # ],
-    'mangapanda_com': [
-        r'mangapanda\.com/.',
+    # 'mangapanda_com': [
+    #     r'mangapanda\.com/.',
+    # ],
+    'mangapanda_onl': [
+        r'mangapanda\.onl/.',
     ],
     'mangapark_me': [
         r'mangapark\.net/manga/.',
     ],
+    'mangareader_cc': [
+        r'mangareader\.cc/manga/.',
+    ],
     'mangareader_net': [
         r'mangareader\.net/.',
     ],
