@@ -7,7 +7,7 @@ class MangaHeavenClub(Provider, Std):
         ch = self.re.search(r'-chapter-(\d+(?:\.\d+)?)', self.chapter)
         return ch.group(1).replace('.', '-')
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/read-manga/{}')
 
     def get_manga_name(self) -> str:
