@@ -8,7 +8,7 @@ class MangaPandaCom(Provider, Std):
         idx = self.re.search(r'\.\w{2,7}/[^/]+/([^/]+)', self.chapter)
         return idx.group(1)
 
-    def get_main_content(self):
+    def get_content(self):
         return self._get_content('{}/{}')
 
     def get_manga_name(self) -> str:
